pub type AuthorityId = Public;Expand description
Identity of a BEEFY authority using BLS as its crypto.
Aliased Type
pub struct AuthorityId(/* private fields */);Trait Implementations
Sourceimpl AuthorityIdBound for AuthorityId
impl AuthorityIdBound for AuthorityId
Sourcetype BoundedSignature = Signature
type BoundedSignature = Signature
Necessary bounds on the Signature associated with the AuthorityId
Sourceimpl BeefyAuthorityId for AuthorityId
impl BeefyAuthorityId for AuthorityId
Sourcefn get_all_public_keys_from_store(store: KeystorePtr) -> Vec<impl AsRef<[u8]>>
fn get_all_public_keys_from_store(store: KeystorePtr) -> Vec<impl AsRef<[u8]>>
Get all the public keys of the current type from a provided
Keystore.